
import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;

import org.springframework.core.io.Resource;
import org.springframework.web.context.support.XmlWebApplicationContext;

/**
 * <b>ConditionalConfigurationXmlWebApplicationContext</b>
 * - Création d'une classe ConditionalConfigurationXmlWebApplicationContext étendant la classe standard XmlWebApplicationContext Spring 
 * - Cette classe permet de le filtrage des imports/ressources lors du chargement du context spring générale ApplicationContext.xml
 * - Cette classe est totalement cutomizable pour filtrer les ressources dans les imports ou même le surchargement de beans
 * 
 */
public class ConditionalConfigurationXmlWebApplicationContext extends XmlWebApplicationContext {

	/**
	 * Map contenant les ressources à ne pas charger
	 */
	private Map<String, Boolean> locationPatternRessourceNOLoad = new HashMap<String, Boolean>();
	
	/**
	 * Méthode appellée et retournant les fichiers paramétrés dans le paramètre "contextConfigLocation" du fichier web.xml 
	 */
	/*@Override
	public String[] getConfigLocations() {
		//locations = append(locations, "classpath*:/META-INF/config/service-module-test-only.xml");
		//setConfigLocations(locations);
		return super.getConfigLocations();
	}*/

	/**
	 * Sets a default config location if no explicit config location specified. 
	 */
	public ConditionalConfigurationXmlWebApplicationContext() {
		super();
		// Exemple de filtrage wf
		{
	        InputStream in = null;
			try{
				String name = "file3.properties";
		        Properties result = null;
		        ClassLoader  loader = this.getClassLoader();
		        if (loader == null){
		        	loader = ClassLoader.getSystemClassLoader ();
		        }
	            in = loader.getResourceAsStream (name);
	            if (in != null){
                    result = new Properties ();
					result.load(in); // Can throw IOException
	            }
	            //for (Iterator iterator = result.keySet().iterator(); iterator.hasNext();) {
	            //	Object key = iterator.next();
				//	Object value = result.get(key);
				//	System.out.println(key+"="+value);
	            //}
	        
	            Object val = result.get("huo.config.wf.enable");
	            if(val != null){
           			locationPatternRessourceNOLoad.put("classpath:huo-spring-wf.xml", Boolean.parseBoolean(val.toString()));
	            }

			}catch (Throwable ignore){
	        }finally{
	            if (in != null) try { in.close (); } catch (Throwable ignore) {}
	        }
		}
	}

   
	/**
	 * Resolve the given location pattern into Resource objects. 
	 */
	@Override
	public Resource[] getResources(String locationPattern) throws IOException{
		{
			Boolean toLoad = true;
			if(locationPatternRessourceNOLoad.containsKey(locationPattern)){
				toLoad = locationPatternRessourceNOLoad.get(locationPattern);
			}
			if(toLoad.booleanValue()){ // LOAD
				return super.getResources(locationPattern);
			}else{ // NO LOAD
				return new Resource[]{};
			}
		}
		
	}

}